require "logger"

class CompositeLogger < Logger
  VERSION = [
    VERSION_MAJOR = 1,
    VERSION_MINOR = 2,
    VERSION_TINY = 0,
    VERSION_PRE = nil
  ].compact.join(".")

  class Error < RuntimeError; end
  class DatetimeFormatNotSupported < Error; end
  class FormatterNotSupported < Error; end

  def initialize(*loggers)
    @loggers = loggers
    @level = DEBUG
    @logdev = nil
  end

  def formatter=(formatter)
    raise(FormatterNotSupported)
  end

  def formatter
    raise(FormatterNotSupported)
  end

  def datetime_format=(datetime_format)
    raise(DatetimeFormatNotSupported)
  end

  def datetime_format
    raise(DatetimeFormatNotSupported)
  end

  def loggers
    @loggers ||= []
  end

  def <<(message)
    loggers.each { |logger| logger << message }
  end

  def add(severity, message = nil, progname = nil, &block)
    severity ||= UNKNOWN

    return true if severity < @level

    loggers.map { |logger| logger.add(severity, message, progname, &block) }
  end
end
